==> kubernetes-model-1.0.44-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableOAuthAccessToken.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableOAuthAccessToken extends OAuthAccessTokenFluentImpl<DoneableOAuthAccessToken> implements Doneable<OAuthAccessToken>, OAuthAccessTokenFluent<DoneableOAuthAccessToken>{


    private final OAuthAccessTokenBuilder builder;    private final Function<OAuthAccessToken, OAuthAccessToken> function;
    public DoneableOAuthAccessToken ( Function<OAuthAccessToken, OAuthAccessToken> function){
    this.builder=new OAuthAccessTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAccessToken ( OAuthAccessToken item,  Function<OAuthAccessToken, OAuthAccessToken> function){
    this.builder=new OAuthAccessTokenBuilder(this, item);this.function=function;
}
    public DoneableOAuthAccessToken ( OAuthAccessToken item){
    this.builder=new OAuthAccessTokenBuilder(this, item);this.function=new Function<OAuthAccessToken, OAuthAccessToken>() {
    public OAuthAccessToken apply(OAuthAccessToken item) {
        return item;
    }
}
;
}

    public OAuthAccessToken done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableOAuthAccessToken.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DoneableOAuthAccessToken extends OAuthAccessTokenFluentImpl<DoneableOAuthAccessToken> implements Doneable<OAuthAccessToken>,OAuthAccessTokenFluent<DoneableOAuthAccessToken>{


    private final OAuthAccessTokenBuilder builder;    private final Function<OAuthAccessToken, OAuthAccessToken> function;
    public DoneableOAuthAccessToken ( Function<OAuthAccessToken, OAuthAccessToken> function){
    this.builder=new OAuthAccessTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAccessToken ( OAuthAccessToken item,  Function<OAuthAccessToken, OAuthAccessToken> function){
    this.builder=new OAuthAccessTokenBuilder(this);this.function=function;
}
    public DoneableOAuthAccessToken ( OAuthAccessToken item){
    this.builder=new OAuthAccessTokenBuilder(this, item);this.function=new Function<OAuthAccessToken, OAuthAccessToken>() {
    public OAuthAccessToken apply(OAuthAccessToken item) {
        return item;
    }
}
;
}

    public OAuthAccessToken done(){
     return function.apply(builder.build());
}


}
